@@ -1,5 +1,5 @@
 /*
- * ampr-ripd.c - AMPR 44net RIPv2 Listner Version 2.4
+ * ampr-ripd.c - AMPR 44net RIPv2 Listner Version 2.4.1
  *
  * Author: Marius Petrescu, YO2LOJ, <marius@yo2loj.ro>
  *
@@ -111,21 +111,21 @@
  *    2.4     15.Aug.2017    Corrected a segfault in NL handling on some systems (Tnx. Steve, VK5ASF & Bent, OZ6BL)
  *                           Corrected a segfault on SIGHUP if call home not set (Tnx. Steve, VK5ASF & Bent, OZ6BL)
  *                           Improved command line handling
+ *    2.4.1    8.Dec.2021    Corrected a bug in netlink debug code (tnx. Daniele, IU5HKX)
+ *                           It should not impact regular compiles without NL_DEBUG.
  */
 
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>
 #include <signal.h>
-#include <fcntl.h>
-#include <asm/types.h>
+#include <bits/getopt_core.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-#include <sys/stat.h>
-#include <net/route.h>
 #include <linux/netlink.h>
 #include <linux/rtnetlink.h>
 #include <netdb.h>
@@ -137,7 +137,7 @@
 #include <time.h>
 #include <ctype.h>
 
-#define AMPR_RIPD_VERSION	"2.4"
+#define AMPR_RIPD_VERSION	"2.4.1"
 
 #define RTSIZE		1000	/* maximum number of route entries */
 #define EXPTIME		600	/* route expiration in seconds */
@@ -998,7 +998,7 @@ void nl_debug(void *msg, int len)
 		
 		    for (i=0; i<((struct nlmsghdr *)msg)->nlmsg_len; i++)
 		    {
-			c = (unsigned char *)&msg;
+			c = (unsigned char *)msg;
 			fprintf(stderr, "%u ", c[i]);
 		    }
 		    fprintf(stderr, "\n");
